(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     43574,       1040]*)
(*NotebookOutlinePosition[     44218,       1062]*)
(*  CellTagsIndexPosition[     44174,       1058]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["CreditMatrix",
  FontColor->RGBColor[1, 0, 0]]], "Subtitle"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Poznamky",
  FontColor->RGBColor[1, 0, 0]]], "Subsection"],

Cell["\<\
 + pro info jsem rozdelil na podrocni a nadrocni, neni ale pravda, ze \
kapitalove pozadavky jsou zvlast pro podrocni i nadrocni, protoze jsou v \
modelu zahrnuty celkove korelace podrocnich i nadrocnich uveru
 + vse pocitano vcetne uroku
+ vyznamna urychleni vypoctu:
    \t- pri prirazovani budouciho ratingu dle nagenerovane hodnoty firmy se \
predpoklada nejprve minuly rating, pote az ostatni (puvodne - prochazely se \
ratingy postupne od AAA po default)
    \t- pri generovani budoucich scenaru se pocita u multinormalniho \
rozdeleni Cholesky rozklad pouze jednou
+ podrocni uroceni je jednoduche, nadrocni je slozene
+ generuji z normalniho rozdeleni s rozptylem rovnym 4, aby korelacni matice \
mela vyrazneji pozitivni determinant
+ z historickych duvodu vstupuje do modelu necerpana cast a dve sady \
urokovych mer (pri vypoctu se neuziji)   \t\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Technicka nastaveni",
  FontColor->RGBColor[1, 0, 0]]], "Subsection"],

Cell[BoxData[{
    RowBox[{"<<", 
      StyleBox[
        RowBox[{"Statistics", 
          StyleBox["`",
            "MB"], "MultinormalDistribution", 
          StyleBox["`",
            "MB"]}]]}], "\[IndentingNewLine]", \(<< 
      Graphics`Graphics`\), "\[IndentingNewLine]", 
    RowBox[{"<<", 
      StyleBox[
        RowBox[{"Miscellaneous", 
          StyleBox["`",
            "MB"], "Calendar", 
          StyleBox["`",
            "MB"]}]]}], "\[IndentingNewLine]", 
    RowBox[{" ", \(SeedRandom[1];\)}]}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Nastaveni modelu",
  FontColor->RGBColor[1, 0, 0]]], "Subsection"],

Cell[TextData[{
  StyleBox["RC (Rating Classes) ",
    FontWeight->"Bold"],
  "- pocet ratingovych trid, vcetne defaultu\n",
  StyleBox["Tres (Tresholds) ",
    FontWeight->"Bold"],
  "-prahove hodnoty ROA (ROE) pro prechod mezi ratingovymi tridami \n",
  StyleBox["Scen (Scenarios) ",
    FontWeight->"Bold"],
  "- jednotlive nagenerovane scenare\n0 = jednoraz, 1 = postupne splatny"
}], "Text"],

Cell[BoxData[{
    \(\(RC = 18;\)\ \), "\[IndentingNewLine]", 
    \(\(n = 1000;\)\  (*\ pocet\ uveru\ *) \), "\[IndentingNewLine]", 
    \(\(NIndustry = 16;\)\), "\[IndentingNewLine]", 
    \(\(NRegions = 6;\)\), "\[IndentingNewLine]", 
    \(\(NScenarios = 25000;\)\), "\[IndentingNewLine]", 
    \(\(ND = NormalDistribution[0, 2];\)\), "\[IndentingNewLine]", 
    \(\(TodayDate = 38625;\)\), "\[IndentingNewLine]", 
    \(\(\(FutureDate = 38990;\);\)\), "\[IndentingNewLine]", 
    \(\(Months\  = 96;\)\), "\[IndentingNewLine]", 
    \(\(Pribor = 0.0157;\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Nacteni  portfolia",
  FontColor->RGBColor[1, 0, 0]]], "Subsection"],

Cell[BoxData[{
    \(\(Pom = 
        ReadList["\<d:\\vypocet\\firm.txt\>", 
          Number];\)\), "\[IndentingNewLine]", 
    \(\(MatrixForm[Firm = Partition[Pom, 12]];\)\), "\[IndentingNewLine]", 
    \(\(Table[
        ToExpression[Firm[\([i, j]\)]], {i, 1, n}, {j, 1, 
          5}];\)\), "\[IndentingNewLine]", 
    \(\(Table[
        ToExpression[Firm[\([i, j]\)]], {i, 1, n}, {j, 8, 
          12}];\)\), "\[IndentingNewLine]", 
    \(MatrixForm[Table[Firm[\([i]\)], {i, 1, 10}]]\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Nacteni tabulek",
  FontColor->RGBColor[1, 0, 0]]], "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
  "Matice prechodu - ",
  StyleBox["TransMat",
    FontColor->RGBColor[0, 0, 1]]
}], "Subsubsection"],

Cell[BoxData[{
    \(\(Pom = 
        ReadList["\<d:\\Vypocet\\TransMat.txt\>", 
          Number];\)\), "\[IndentingNewLine]", 
    \(MatrixForm[TransMat = Partition[Pom, RC]]\), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Stanoveni prahu prechodu - ",
  StyleBox["Tres",
    FontColor->RGBColor[0, 0, 1]]
}], "Subsubsection"],

Cell[BoxData[{\(CumTransMat = 
        Table[Sum[
            TransMat\[LeftDoubleBracket]i, j\[RightDoubleBracket], {j, k, 
              RC}], {i, 1, RC - 1}, {k, 1, RC}];\), "\[IndentingNewLine]", 
    RowBox[{\(MatrixForm[
          N[Tres = 
              Table[Quantile[ND, 
                  CumTransMat\[LeftDoubleBracket]i, j\[RightDoubleBracket]/
                    100], {i, 1, RC - 1}, {j, 2, RC}], 2]];\), 
      "\[IndentingNewLine]", \( (*\ 
        pridam\ na\ konec\  - \[Infinity]*) \)}], "\[IndentingNewLine]", 
    RowBox[{"MatrixForm", "[", 
      RowBox[{"Tres", "=", 
        RowBox[{"Partition", "[", 
          RowBox[{
            RowBox[{"Flatten", "[", 
              RowBox[{"N", "[", 
                RowBox[{"Table", "[", 
                  RowBox[{
                    RowBox[{"{", 
                      
                      RowBox[{\(Tres\[LeftDoubleBracket]
                          i\[RightDoubleBracket]\), ",", 
                        InterpretationBox[\(-\[Infinity]\),
                          DirectedInfinity[ -1]]}], "}"}], 
                    ",", \({i, 1, RC - 1}\)}], "]"}], "]"}], "]"}], ",", 
            "RC"}], "]"}]}], "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Korelacni matice - ",
  StyleBox["CorrMatInd, CorrMatReg",
    FontColor->RGBColor[0, 0, 1]]
}], "Subsubsection"],

Cell[BoxData[{
    \(\(Pom = 
        ReadList["\<d:\\Vypocet\\CorrMatInd.txt\>", 
          Number];\)\), "\[IndentingNewLine]", 
    \(MatrixForm[
      CorrMatInd = Partition[Pom, NIndustry]]\), "\[IndentingNewLine]", 
    \(\(Pom = 
        ReadList["\<d:\\Vypocet\\CorrMatReg.txt\>", 
          Number];\)\), "\[IndentingNewLine]", 
    \(MatrixForm[CorrMatReg = Partition[Pom, NRegions]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Pocet dni - ",
  StyleBox["NoDays, TotNoDays, NoMonths",
    FontColor->RGBColor[0, 0, 1]]
}], "Subsubsection"],

Cell[BoxData[{
    \(\(NoDaysInMth = 
        Table[DaysBetween[{2005 + Quotient[8 + j + 1, 12], 
              Mod[8 + j + 1, 12] + 1, 1}, {2005 + Quotient[8 + j, 12], 
              Mod[8 + j, 12] + 1, 1}], {j, 1, 
            Months}];\)\), "\[IndentingNewLine]", 
    \(SumDays = 
      Table[Sum[
          NoDaysInMth\[LeftDoubleBracket]i\[RightDoubleBracket], {i, 1, 
            j}], {j, 1, Months}]\), "\[IndentingNewLine]", 
    \(\(SumDays = \ Insert[SumDays, 0, 1];\)\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(MatrixForm[
        NoDays = 
          Table[Min[NoDaysInMth\[LeftDoubleBracket]j\[RightDoubleBracket], 
              Max[0, Firm\[LeftDoubleBracket]i, 5\[RightDoubleBracket] - 
                  TodayDate - 
                  SumDays\[LeftDoubleBracket]j\[RightDoubleBracket]]], {i, 1, 
              n}, {j, 1, Months}]];\)\), "\[IndentingNewLine]", 
    \(\(NoDays = 
        Table[If[NoDays\[LeftDoubleBracket]i, k\[RightDoubleBracket] == 0, 0, 
            Sum[NoDays\[LeftDoubleBracket]i, j\[RightDoubleBracket], {j, 1, 
                k}]], {i, 1, n}, {k, 1, 
            Months - 1}];\)\), "\[IndentingNewLine]", 
    \(\(MatrixForm[
        Table[NoDays\[LeftDoubleBracket]i\[RightDoubleBracket] = 
            Insert[NoDays\[LeftDoubleBracket]i\[RightDoubleBracket], 0, 
              1], {i, 1, n}]];\)\), "\[IndentingNewLine]", 
    \(\(NoMonths = 
        Table[Sum[
            Ceiling[NoDays\[LeftDoubleBracket]i, j\[RightDoubleBracket]/
                100000], {j, 1, Months - 1}], {i, 1, 
            n}];\)\), "\[IndentingNewLine]", 
    \(\(TotNoDays = 
        Table[Firm\[LeftDoubleBracket]i, 5\[RightDoubleBracket] - 
            TodayDate, {i, 1, n}];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Dluzna castka - ",
  StyleBox["AmoutDue",
    FontColor->RGBColor[0, 0, 1]]
}], "Subsubsection"],

Cell[BoxData[{
    \(\(AmountDue = NoDays;\)\), "\[IndentingNewLine]", 
    \(\(Table[
        If[Firm\[LeftDoubleBracket]i, 6\[RightDoubleBracket] == 0, 
          If[NoDays\[LeftDoubleBracket]i, j\[RightDoubleBracket] == 0, 
            AmountDue\[LeftDoubleBracket]i, j\[RightDoubleBracket] = 0, 
            AmountDue\[LeftDoubleBracket]i, j\[RightDoubleBracket] = 
              Firm\[LeftDoubleBracket]i, 2\[RightDoubleBracket]], 
          If[NoDays\[LeftDoubleBracket]i, j\[RightDoubleBracket] \[Equal] 0, 
            AmountDue\[LeftDoubleBracket]i, j\[RightDoubleBracket] = 0, 
            AmountDue\[LeftDoubleBracket]i, j\[RightDoubleBracket] = 
              Firm\[LeftDoubleBracket]i, 2\[RightDoubleBracket]*
                Max[0, 1.  - 
                    NoDays\[LeftDoubleBracket]i, j\[RightDoubleBracket]/
                      TotNoDays\[LeftDoubleBracket]
                        i\[RightDoubleBracket]]]], {i, 1, n}, {j, 1, 
          Months}];\)\), "\[IndentingNewLine]", 
    \(\(Table[
        AmountDue\[LeftDoubleBracket]i, 1\[RightDoubleBracket] = 
          Firm\[LeftDoubleBracket]i, 2\[RightDoubleBracket], {i, 1, 
          n}];\)\), "\[IndentingNewLine]", 
    \(\(MatrixForm[
        AmountDue = Round[AmountDue]];\)\), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "PD, Rizikove naklady - ",
  StyleBox["PD, RNj, RNp",
    FontColor->RGBColor[0, 0, 1]]
}], "Subsubsection"],

Cell[BoxData[{
    \(PD = 
      ReadList["\<d:\\Vypocet\\PD.txt\>", Number]\), "\[IndentingNewLine]", 
    \(\(RNj = 
        Table[PD\[LeftDoubleBracket]
              i\[RightDoubleBracket]/\((1 - 
                PD\[LeftDoubleBracket]i\[RightDoubleBracket]/2)\), {i, 1, 
            RC - 1}];\)\), "\[IndentingNewLine]", 
    \(\(RNp = 
        Table[PD\[LeftDoubleBracket]
              i\[RightDoubleBracket]/\((1 - 
                PD\[LeftDoubleBracket]i\[RightDoubleBracket]/3)\), {i, 1, 
            RC - 1}];\)\), "\[IndentingNewLine]", 
    \(RNj = {RNj, 0} // Flatten\), "\[IndentingNewLine]", 
    \(RNp = {RNp, 0} // Flatten\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Splatky - ",
  StyleBox["Payments",
    FontColor->RGBColor[0, 0, 1]]
}], "Subsubsection"],

Cell[BoxData[{
    \(Payments = NoDays; \ 
    Table[Payments\[LeftDoubleBracket]i, 1\[RightDoubleBracket] = 0, {i, 1, 
        n}];\), "\[IndentingNewLine]", 
    \(\(MatrixForm[
        Table[Payments\[LeftDoubleBracket]i, j\[RightDoubleBracket] = 
            AmountDue\[LeftDoubleBracket]i, j - 1\[RightDoubleBracket]*
                Firm\[LeftDoubleBracket]i, 8\[RightDoubleBracket]/
                  100. *\((Max[0, 
                      NoDays\[LeftDoubleBracket]i, j\[RightDoubleBracket] - 
                        NoDays\[LeftDoubleBracket]i, 
                          j - 1\[RightDoubleBracket]])\)/365 + 
              If[Firm\[LeftDoubleBracket]i, 6\[RightDoubleBracket] \[Equal] 
                  0, AmountDue\[LeftDoubleBracket]i, j\[RightDoubleBracket] - 
                  AmountDue\[LeftDoubleBracket]i, j + 1\[RightDoubleBracket], 
                AmountDue\[LeftDoubleBracket]i, j - 1\[RightDoubleBracket] - 
                  AmountDue\[LeftDoubleBracket]i, 
                    j\[RightDoubleBracket]], {i, 1, n}, {j, 2, 
            Months - 1}]];\)\), "\[IndentingNewLine]", 
    \(\(MatrixForm[Payments];\)\)}], "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Dnesni hodnota portfolia",
  FontColor->RGBColor[1, 0, 0]]], "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
  "Dnesni hodnota portfolia - ",
  StyleBox["PV",
    FontColor->RGBColor[0, 0, 1]]
}], "Subsubsection"],

Cell[BoxData[{
    \(Timing[\(MatrixForm[
          PV1 = Table[
              If[NoMonths\[LeftDoubleBracket]
                    i\[RightDoubleBracket] \[LessEqual] 12, 0, 
                Sum[Payments\[LeftDoubleBracket]i, j\[RightDoubleBracket]*
                    If[NoDays\[LeftDoubleBracket]i, 
                          j\[RightDoubleBracket] \[LessEqual] 365, 
                      1/\((1 + 
                            NoDays\[LeftDoubleBracket]i, 
                                  j\[RightDoubleBracket]/
                                365*\((Pribor + 
                                  Firm\[LeftDoubleBracket]i, 
                                      10\[RightDoubleBracket]*
                                    If[Firm\[LeftDoubleBracket]i, 
                                        6\[RightDoubleBracket] \[Equal] 0, 
                                      RNj\[LeftDoubleBracket]
                                        Firm\[LeftDoubleBracket]i, 
                                        7\[RightDoubleBracket]\
\[RightDoubleBracket], RNp\[LeftDoubleBracket]Firm\[LeftDoubleBracket]i, 
                                        7\[RightDoubleBracket]\
\[RightDoubleBracket]])\))\), 
                      1/\((1 + \((Pribor + 
                                  Firm\[LeftDoubleBracket]i, 
                                      10\[RightDoubleBracket]*
                                    If[Firm\[LeftDoubleBracket]i, 
                                        6\[RightDoubleBracket] \[Equal] 0, 
                                      RNj\[LeftDoubleBracket]
                                        Firm\[LeftDoubleBracket]i, 
                                        7\[RightDoubleBracket]\
\[RightDoubleBracket], RNp\[LeftDoubleBracket]Firm\[LeftDoubleBracket]i, 
                                        7\[RightDoubleBracket]\
\[RightDoubleBracket]])\))\)^\((NoDays\[LeftDoubleBracket]i, 
                                j\[RightDoubleBracket]/365)\)], {j, 1, 
                    Months}]], {i, 1, n}]];\)]\), "\[IndentingNewLine]", 
    \(Timing[\(MatrixForm[
          PV2 = Table[
              If[NoMonths\[LeftDoubleBracket]
                    i\[RightDoubleBracket] \[LessEqual] 12, 
                Sum[Payments\[LeftDoubleBracket]i, j\[RightDoubleBracket]*
                    If[NoDays\[LeftDoubleBracket]i, 
                          j\[RightDoubleBracket] \[LessEqual] 365, 
                      1/\((1 + 
                            NoDays\[LeftDoubleBracket]i, 
                                  j\[RightDoubleBracket]/
                                365*\((Pribor + 
                                  Firm\[LeftDoubleBracket]i, 
                                      10\[RightDoubleBracket]*
                                    If[Firm\[LeftDoubleBracket]i, 
                                        6\[RightDoubleBracket] \[Equal] 0, 
                                      RNj\[LeftDoubleBracket]
                                        Firm\[LeftDoubleBracket]i, 
                                        7\[RightDoubleBracket]\
\[RightDoubleBracket], RNp\[LeftDoubleBracket]Firm\[LeftDoubleBracket]i, 
                                        7\[RightDoubleBracket]\
\[RightDoubleBracket]])\))\), 
                      1/\((1 + \((Pribor + 
                                  Firm\[LeftDoubleBracket]i, 
                                      10\[RightDoubleBracket]*
                                    If[Firm\[LeftDoubleBracket]i, 
                                        6\[RightDoubleBracket] \[Equal] 0, 
                                      RNj\[LeftDoubleBracket]
                                        Firm\[LeftDoubleBracket]i, 
                                        7\[RightDoubleBracket]\
\[RightDoubleBracket], RNp\[LeftDoubleBracket]Firm\[LeftDoubleBracket]i, 
                                        7\[RightDoubleBracket]\
\[RightDoubleBracket]])\))\)^\((NoDays\[LeftDoubleBracket]i, 
                                j\[RightDoubleBracket]/365)\)], {j, 1, 13}], 
                0], {i, 1, n}]];\)]\), "\[IndentingNewLine]", 
    \(\(PV1 + PV2;\)\), "\[IndentingNewLine]", 
    \(PV1\  = \ 
      Sum[PV1\[LeftDoubleBracket]i\[RightDoubleBracket], {i, 1, n}]; \ 
    PV2\  = \ Sum[
        PV2\[LeftDoubleBracket]i\[RightDoubleBracket], {i, 1, 
          n}];\), "\[IndentingNewLine]", 
    \(PV = {PV1, PV2, PV1 + PV2}\)}], "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Generovani scenaru",
  FontColor->RGBColor[1, 0, 0]]], "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
  "Korelacni matice - ",
  StyleBox["CorrMat",
    FontColor->RGBColor[0, 0, 1]]
}], "Subsubsection"],

Cell[BoxData[{
    \(Timing[\(MatrixForm[
          CorrMat = 
            Table[CorrMatInd\[LeftDoubleBracket]
                  Firm\[LeftDoubleBracket]i, 12\[RightDoubleBracket], 
                  Firm\[LeftDoubleBracket]j, 
                    12\[RightDoubleBracket]\[RightDoubleBracket] + 
                CorrMatReg\[LeftDoubleBracket]
                  Firm\[LeftDoubleBracket]i, 11\[RightDoubleBracket], 
                  Firm\[LeftDoubleBracket]j, 
                    11\[RightDoubleBracket]\[RightDoubleBracket], {i, 1, 
                n}, {j, 1, n}]];\)]\), "\[IndentingNewLine]", 
    \(\(Table[
        CorrMat\[LeftDoubleBracket]i, i\[RightDoubleBracket] = 1, {i, 1, 
          n}];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Scenare - ",
  StyleBox["Scen",
    FontColor->RGBColor[0, 0, 1]]
}], "Subsubsection"],

Cell[BoxData[{
    \(\(Nuly = Table[0, {i, 1, n}];\)\), "\[IndentingNewLine]", 
    \(\ \(SeedRandom[1];\)\), "\[IndentingNewLine]", 
    \(Timing[\(MatrixForm[
          Transpose[
            Scen\  = \ 
              RandomArray[
                MultinormalDistribution[Nuly, 
                  4*CorrMat], {NScenarios}]]\ ];\)]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Budouci ratingy - ",
  StyleBox["FRatings",
    FontColor->RGBColor[0, 0, 1]]
}], "Subsubsection"],

Cell[BoxData[
    \(\(\( (*\ a - ta\ akcie, b\ puvodni\ rating, \ 
      k\ scenar\ *) \)\(\[IndentingNewLine]\)\(\(rat[a_, b_, k_] := 
        If[b > 1 && 
            Tres\[LeftDoubleBracket]b, b\[RightDoubleBracket] < 
              Scen\[LeftDoubleBracket]k, a\[RightDoubleBracket] < 
              Tres\[LeftDoubleBracket]b, b - 1\[RightDoubleBracket], b, 
          rata[a, b, k]];\)\[IndentingNewLine]
    \(rata[a_, b_, 
          k_] := {i = 1, 
            While[Scen\[LeftDoubleBracket]k, a\[RightDoubleBracket] < 
                Tres\[LeftDoubleBracket]b, i\[RightDoubleBracket], \(i++\)], 
            i}\[LeftDoubleBracket]3\[RightDoubleBracket];\)\[IndentingNewLine]\

    Timing[\(MatrixForm[
          FRatings = 
            Transpose[
              Table[rat[i, Firm\[LeftDoubleBracket]i, 7\[RightDoubleBracket], 
                  k], {k, 1, NScenarios}, {i, 1, n}]]];\)]\)\)\)], "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Budouci hodnota",
  FontColor->RGBColor[1, 0, 0]]], "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
  "Budouci hodnota portfolia pro \[UAcute]v\:011bry del\[SHacek]\[IAcute] ne\
\:017e rok (se zahrnutim uroku behem casoveho horizontu) - ",
  StyleBox["FV1",
    FontColor->RGBColor[0, 0, 1]]
}], "Subsubsection"],

Cell[BoxData[{
    \(\(MatrixForm[
        xDiscountsJ = 
          Table[If[j \[LessEqual] 12, 
              1/\((1 + \((SumDays\[LeftDoubleBracket]
                              j + 12\[RightDoubleBracket] - 365)\)/
                        365*\((Pribor + 
                          LG/100*
                            RNj\[LeftDoubleBracket]
                              i\[RightDoubleBracket])\))\), 
              1/\((1 + \((Pribor + 
                          LG/100*
                            RNj\[LeftDoubleBracket]
                              i\[RightDoubleBracket])\))\)^\((\((SumDays\
\[LeftDoubleBracket]j + 12\[RightDoubleBracket] - 365)\)/365)\)], {i, 1, 
              RC - 1}, {j, 1, Months - 12}, {LG, 0, 
              100}]];\)\), "\[IndentingNewLine]", 
    \(\(MatrixForm[
        xDiscountsP = 
          Table[If[j \[LessEqual] 12, 
              1/\((1 + \((SumDays\[LeftDoubleBracket]
                              j + 12\[RightDoubleBracket] - 365)\)/
                        365*\((Pribor + 
                          LG/100*
                            RNp\[LeftDoubleBracket]
                              i\[RightDoubleBracket])\))\), 
              1/\((1 + \((Pribor + 
                          LG/100*
                            RNp\[LeftDoubleBracket]
                              i\[RightDoubleBracket])\))\)^\((\((SumDays\
\[LeftDoubleBracket]j + 12\[RightDoubleBracket] - 365)\)/365)\)], {i, 1, 
              RC - 1}, {j, 1, Months - 12}, {LG, 0, 100}]];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Pom = 
        Table[If[
            Firm\[LeftDoubleBracket]i, 6\[RightDoubleBracket] \[Equal] 0, 
            AmountDue\[LeftDoubleBracket]i, 
                1\[RightDoubleBracket]*\((\((1 - 
                      Firm\[LeftDoubleBracket]i, 
                        10\[RightDoubleBracket])\) + \(Firm\
\[LeftDoubleBracket]i, 8\[RightDoubleBracket]/100\)/2)\), 
            Sum[Payments\[LeftDoubleBracket]i, j\[RightDoubleBracket], {j, 1, 
                  6}] + \((AmountDue\[LeftDoubleBracket]i, 
                        13\[RightDoubleBracket] + 
                      AmountDue\[LeftDoubleBracket]i, 
                        1\[RightDoubleBracket])\)/
                  2*\((1 - 
                    Firm\[LeftDoubleBracket]i, 
                      10\[RightDoubleBracket])\)], {i, 1, 
            n}];\)\), "\[IndentingNewLine]", 
    \(\(\(UnderYear = 
        Table[Sum[
            If[NoMonths\[LeftDoubleBracket]i\[RightDoubleBracket] > 12, 
              Payments\[LeftDoubleBracket]i, 
                  j\[RightDoubleBracket]*\((1 + 
                    Pribor/365*\((365 - 
                          NoDays\[LeftDoubleBracket]i, 
                            j\[RightDoubleBracket])\))\), 0], {j, 1, 
              13}], {i, 1, n}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(FV1 = 
        Table[0, {i, 1, n}, {k, 1, NScenarios}];\)\), "\[IndentingNewLine]", 
    \(Timing[\(Table[
          If[Mod[i, n/20] \[Equal] 0, 
            Print[IntegerPart[\((\((i + 1)\)*20/n)\)] "\<. dvacetina\>"]]; 
          FV1[\([i]\)] = 
            Table[If[
                  FRatings\[LeftDoubleBracket]i, k\[RightDoubleBracket] < RC, 
                  Sum[Payments\[LeftDoubleBracket]i, 
                          j + 13\[RightDoubleBracket]*
                        If[Firm\[LeftDoubleBracket]i, 6\[RightDoubleBracket] == 
                            0, xDiscountsJ\[LeftDoubleBracket]
                            FRatings\[LeftDoubleBracket]i, 
                              k\[RightDoubleBracket], j + 1, 
                            Firm\[LeftDoubleBracket]i, 
                                10\[RightDoubleBracket]*100\
\[RightDoubleBracket]\ , 
                          xDiscountsP\[LeftDoubleBracket]
                            FRatings\[LeftDoubleBracket]i, 
                              k\[RightDoubleBracket], j + 1, 
                            Firm\[LeftDoubleBracket]i, 
                                10\[RightDoubleBracket]*100\
\[RightDoubleBracket]\ ], {j, 1, Months - 13}] + \ 
                    UnderYear\[LeftDoubleBracket]i\[RightDoubleBracket], 
                  If[TotNoDays\[LeftDoubleBracket]i\[RightDoubleBracket] > 
                      365, Pom\[LeftDoubleBracket]i\[RightDoubleBracket], 
                    0]], {k, 1, NScenarios}]/\((1 + Pribor)\), {i, 1, 
            n}];\)]\), "\[IndentingNewLine]", 
    \(\(Sum[
        FV1\[LeftDoubleBracket]i\[RightDoubleBracket], {i, 1, 
          n}];\)\), "\[IndentingNewLine]", 
    \(\(Sort[
        Sum[FV1\[LeftDoubleBracket]i\[RightDoubleBracket], {i, 1, 
            n}]];\)\), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Budouci hodnota portfolia pro \[UAcute]v\:011bry krat\[SHacek]\[IAcute] ne\
\:017e rok - ",
  StyleBox["FV2",
    FontColor->RGBColor[0, 0, 1]]
}], "Subsubsection"],

Cell[BoxData[
    \(Timing[\(Ratings2 = 
          Table[If[TotNoDays\[LeftDoubleBracket]i\[RightDoubleBracket] < 365, 
              Quantile[ND, 
                TransMat\[LeftDoubleBracket]
                      Firm\[LeftDoubleBracket]i, 7\[RightDoubleBracket], 
                      RC\[RightDoubleBracket]/100*
                  TotNoDays\[LeftDoubleBracket]i\[RightDoubleBracket]/365], 
              9999], {i, 1, n}];\)]\)], "Input"],

Cell[BoxData[{
    \(Timing[\(NonDefault = 
          Table[Sum[
              If[NoMonths\[LeftDoubleBracket]
                    i\[RightDoubleBracket] \[LessEqual] 12, 
                Payments\[LeftDoubleBracket]i, 
                    j\[RightDoubleBracket]*\((1 + 
                      Pribor/365*\((365 - 
                            NoDays\[LeftDoubleBracket]i, 
                              j\[RightDoubleBracket])\))\), 0], {j, 1, 
                13}], {i, 1, n}];\)]\), "\[IndentingNewLine]", 
    \(Timing[\(IsDefault = 
          Table[If[
              Firm\[LeftDoubleBracket]i, 6\[RightDoubleBracket] \[Equal] 0, 
              AmountDue\[LeftDoubleBracket]i, 1\[RightDoubleBracket]*
                  Firm\[LeftDoubleBracket]i, 8\[RightDoubleBracket]/
                    100*\((\(TotNoDays\[LeftDoubleBracket]
                          i\[RightDoubleBracket]/365\)/2)\) + 
                AmountDue\[LeftDoubleBracket]i, 
                    1\[RightDoubleBracket]*\((1 - Firm[\([i, 10]\)])\)*\((1 + 
                      Pribor*\((1 - \(TotNoDays\[LeftDoubleBracket]
                                  i\[RightDoubleBracket]/2\)/
                              365)\))\), \((AmountDue\[LeftDoubleBracket]i, 
                        1 + IntegerPart[
                            NoMonths\[LeftDoubleBracket]
                                i\[RightDoubleBracket]/
                              2]\[RightDoubleBracket]*\((1 - 
                          Firm\[LeftDoubleBracket]i, 
                            10\[RightDoubleBracket])\) + 
                    Sum[Payments\[LeftDoubleBracket]i, 
                        j\[RightDoubleBracket], {j, 1, 
                        1 + IntegerPart[
                            NoMonths\[LeftDoubleBracket]
                                i\[RightDoubleBracket]/2]}])\)*\((1 + 
                    Pribor*\((1 - \(TotNoDays\[LeftDoubleBracket]
                                i\[RightDoubleBracket]/2\)/365)\))\)], {i, 1, 
              n}];\)]\), "\[IndentingNewLine]", 
    \(Timing[\(MatrixForm[
          FV2 = Table[
                If[Scen\[LeftDoubleBracket]k, i\[RightDoubleBracket] < 
                      Ratings2\[LeftDoubleBracket]i\[RightDoubleBracket] && 
                    NoMonths\[LeftDoubleBracket]
                        i\[RightDoubleBracket] \[LessEqual] 12, 
                  IsDefault\[LeftDoubleBracket]i\[RightDoubleBracket], 
                  NonDefault\[LeftDoubleBracket]i\[RightDoubleBracket]], {i, 
                  1, n}, {k, 1, NScenarios}]/\((1 + 
                  Pribor)\)];\)]\), "\[IndentingNewLine]", 
    \(\(Sort[Sum[FV2[\([i]\)], {i, 1, n}]];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Celkov\[AAcute] budouci hodnota portfolia - ",
  StyleBox["FV",
    FontColor->RGBColor[0, 0, 1]]
}], "Subsubsection"],

Cell[BoxData[
    \(\(FVV = {Sum[FV1\[LeftDoubleBracket]i\[RightDoubleBracket], {i, 1, n}], 
          Sum[FV2\[LeftDoubleBracket]i\[RightDoubleBracket], {i, 1, n}], 
          Sum[FV1\[LeftDoubleBracket]i\[RightDoubleBracket] + 
              FV2\[LeftDoubleBracket]i\[RightDoubleBracket], {i, 1, 
              n}]};\)\)], "Input"],

Cell[BoxData[
    \({Histogram[FVV\[LeftDoubleBracket]1\[RightDoubleBracket]], 
      Histogram[FVV\[LeftDoubleBracket]2\[RightDoubleBracket]], 
      Histogram[FVV\[LeftDoubleBracket]3\[RightDoubleBracket]]}\)], "Input"],

Cell[BoxData[{
    \(\(FVV[\([1]\)] = 
        Sort[FVV\[LeftDoubleBracket]1\[RightDoubleBracket]];\)\), "\
\[IndentingNewLine]", 
    \(\(FVV[\([2]\)] = 
        Sort[FVV\[LeftDoubleBracket]2\[RightDoubleBracket]];\)\), "\
\[IndentingNewLine]", 
    \(\(FVV[\([3]\)] = 
        Sort[FVV\[LeftDoubleBracket]3\[RightDoubleBracket]];\)\), "\
\[IndentingNewLine]", 
    \(EX = 
      Table[Sum[
            FVV\[LeftDoubleBracket]j, i\[RightDoubleBracket], {i, 1, 
              NScenarios}]/NScenarios, {j, 1, 3}]\), "\[IndentingNewLine]", 
    \(\(\(Kvantil = 
      Table[FVV\[LeftDoubleBracket]j, 
          IntegerPart[NScenarios/100] + 1\[RightDoubleBracket], {j, 1, 
          3}]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(KPCredit1 = 
      EX - Table[
          FVV\[LeftDoubleBracket]j, 
            IntegerPart[NScenarios/100]\[RightDoubleBracket], {j, 1, 
            3}]\), "\[IndentingNewLine]", 
    \(KPCredit2 = 
      EX - Table[
          FVV\[LeftDoubleBracket]j, 
            IntegerPart[NScenarios/200]\[RightDoubleBracket], {j, 1, 
            3}]\), "\[IndentingNewLine]", 
    \(KPCredit3 = 
      EX - Table[
          FVV\[LeftDoubleBracket]j, 
            IntegerPart[NScenarios/500]\[RightDoubleBracket], {j, 1, 
            3}]\), "\[IndentingNewLine]", 
    \(KPCredit4 = 
      EX - Table[
          FVV\[LeftDoubleBracket]j, 
            IntegerPart[NScenarios/1000]\[RightDoubleBracket], {j, 1, 
            3}]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(CMNeocek = {KPCredit1\[LeftDoubleBracket]3\[RightDoubleBracket], 
          KPCredit2\[LeftDoubleBracket]3\[RightDoubleBracket], 
          KPCredit3\[LeftDoubleBracket]3\[RightDoubleBracket], 
          KPCredit4\[LeftDoubleBracket]3\[RightDoubleBracket]};\)\
\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(Shortfall1 = 
      EX - Table[
            Sum[FVV\[LeftDoubleBracket]j, i\[RightDoubleBracket], {i, 1, 
                NScenarios/100}], {j, 1, 3}]/\((NScenarios/
              100)\)\), "\[IndentingNewLine]", 
    \(Shortfall2 = 
      EX - Table[
            Sum[FVV\[LeftDoubleBracket]j, i\[RightDoubleBracket], {i, 1, 
                NScenarios/200}], {j, 1, 3}]/\((NScenarios/
              200)\)\), "\[IndentingNewLine]", 
    \(Shortfall3 = 
      EX - Table[
            Sum[FVV\[LeftDoubleBracket]j, i\[RightDoubleBracket], {i, 1, 
                NScenarios/500}], {j, 1, 3}]/\((NScenarios/
              500)\)\), "\[IndentingNewLine]", 
    \(Shortfall4 = 
      EX - Table[
            Sum[FVV\[LeftDoubleBracket]j, i\[RightDoubleBracket], {i, 1, 
                NScenarios/1000}], {j, 1, 3}]/\((NScenarios/
              1000)\)\)}], "Input"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Vasicek",
  FontColor->RGBColor[1, 0, 0]]], "Subtitle"],

Cell[BoxData[
    \(\(ND = NormalDistribution[0, 1];\)\)], "Input"],

Cell[BoxData[{
    \(\(VEAD = 
        Table[If[
            Firm\[LeftDoubleBracket]i, 6\[RightDoubleBracket] \[Equal] 0, 
            AmountDue\[LeftDoubleBracket]i, 1\[RightDoubleBracket], 
            If[NoMonths\[LeftDoubleBracket]
                  i\[RightDoubleBracket] \[LessEqual] 12, 
              AmountDue\[LeftDoubleBracket]i, 1\[RightDoubleBracket]*
                NoMonths\[LeftDoubleBracket]i\[RightDoubleBracket]/
                  12, \((AmountDue\[LeftDoubleBracket]i, 
                      1\[RightDoubleBracket] + 
                    AmountDue\[LeftDoubleBracket]i, 
                      13\[RightDoubleBracket])\)/2]], {i, 1, 
            n}];\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(VR = 
        Table[1/n*\((350*
                  CorrMatInd\[LeftDoubleBracket]
                    Firm\[LeftDoubleBracket]i, 12\[RightDoubleBracket], 
                    1\[RightDoubleBracket] + 
                11*CorrMatInd[\([Firm\[LeftDoubleBracket]i, 
                        12\[RightDoubleBracket], 2]\)] + 
                2*CorrMatInd[\([Firm\[LeftDoubleBracket]i, 
                        12\[RightDoubleBracket], 3]\)] + 
                37*CorrMatInd[\([Firm\[LeftDoubleBracket]i, 
                        12\[RightDoubleBracket], 4]\)] + 
                29*CorrMatInd\[LeftDoubleBracket]
                    Firm\[LeftDoubleBracket]i, 12\[RightDoubleBracket], 
                    5\[RightDoubleBracket] + 
                58*CorrMatInd[\([Firm\[LeftDoubleBracket]i, 
                        12\[RightDoubleBracket], 6]\)] + 
                24*CorrMatInd[\([Firm\[LeftDoubleBracket]i, 
                        12\[RightDoubleBracket], 7]\)] + 
                17*CorrMatInd[\([Firm\[LeftDoubleBracket]i, 
                        12\[RightDoubleBracket], 8]\)] + 
                12*CorrMatInd\[LeftDoubleBracket]
                    Firm\[LeftDoubleBracket]i, 12\[RightDoubleBracket], 
                    9\[RightDoubleBracket] + 
                53*CorrMatInd[\([Firm\[LeftDoubleBracket]i, 
                        12\[RightDoubleBracket], 10]\)] + 
                12*CorrMatInd[\([Firm\[LeftDoubleBracket]i, 
                        12\[RightDoubleBracket], 11]\)] + 
                44*CorrMatInd[\([Firm\[LeftDoubleBracket]i, 
                        12\[RightDoubleBracket], 12]\)] + 
                139*CorrMatInd\[LeftDoubleBracket]
                    Firm\[LeftDoubleBracket]i, 12\[RightDoubleBracket], 
                    13\[RightDoubleBracket] + 
                49*CorrMatInd[\([Firm\[LeftDoubleBracket]i, 
                        12\[RightDoubleBracket], 14]\)] + 
                6*CorrMatInd[\([Firm\[LeftDoubleBracket]i, 
                        12\[RightDoubleBracket], 15]\)] + 
                157*CorrMatInd[\([Firm\[LeftDoubleBracket]i, 
                        12\[RightDoubleBracket], 16]\)])\), {i, 1, 
            n}];\)\), "\[IndentingNewLine]", 
    \(\(VR2 = 
        Table[1/n*\((127*
                  CorrMatReg\[LeftDoubleBracket]
                    Firm\[LeftDoubleBracket]i, 11\[RightDoubleBracket], 
                    1\[RightDoubleBracket] + 
                17*CorrMatReg\[LeftDoubleBracket]Firm\[LeftDoubleBracket]i, 
                      11\[RightDoubleBracket], 2\[RightDoubleBracket] + 
                223*CorrMatReg\[LeftDoubleBracket]Firm\[LeftDoubleBracket]i, 
                      11\[RightDoubleBracket], 3\[RightDoubleBracket] + 
                228*CorrMatReg\[LeftDoubleBracket]Firm\[LeftDoubleBracket]i, 
                      11\[RightDoubleBracket], 4\[RightDoubleBracket] + 
                58*CorrMatReg\[LeftDoubleBracket]Firm\[LeftDoubleBracket]i, 
                      11\[RightDoubleBracket], 5\[RightDoubleBracket] + 
                347*CorrMatReg\[LeftDoubleBracket]Firm\[LeftDoubleBracket]i, 
                      11\[RightDoubleBracket], 6\[RightDoubleBracket])\), {i, 
            1, n}];\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(VR = VR + VR2;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(PoJednom990 = 
        Table[\((Firm\[LeftDoubleBracket]i, 10\[RightDoubleBracket]*
                CDF[ND, \((Quantile[ND, 0.99]*
                          Sqrt[VR\[LeftDoubleBracket]i\[RightDoubleBracket]] \
+ Quantile[ND, TransMat\[LeftDoubleBracket]Firm\[LeftDoubleBracket]i, 
                                7\[RightDoubleBracket], 
                              RC\[RightDoubleBracket]*
                            Min[1, 
                                TotNoDays\[LeftDoubleBracket]i\
\[RightDoubleBracket]/365]/100] - 
                        Firm\[LeftDoubleBracket]i, 10\[RightDoubleBracket]*
                          TransMat\[LeftDoubleBracket]Firm\[LeftDoubleBracket]\
i, 7\[RightDoubleBracket], RC\[RightDoubleBracket]/100*
                          Min[1, 
                            TotNoDays\[LeftDoubleBracket]i\
\[RightDoubleBracket]/365])\)/
                    Sqrt[1 - 
                        VR\[LeftDoubleBracket]i\[RightDoubleBracket]]])\)*
            VEAD\[LeftDoubleBracket]i\[RightDoubleBracket], {i, 1, 
            n}];\)\), "\[IndentingNewLine]", 
    \(Sum[
      PoJednom990\[LeftDoubleBracket]i\[RightDoubleBracket], {i, 1, 
        n}]\), "\[IndentingNewLine]", 
    \(\(PoJednom995 = 
        Table[\((Firm\[LeftDoubleBracket]i, 10\[RightDoubleBracket]*
                CDF[ND, \((Quantile[ND, 0.995]*
                          Sqrt[VR\[LeftDoubleBracket]i\[RightDoubleBracket]] \
+ Quantile[ND, TransMat\[LeftDoubleBracket]Firm\[LeftDoubleBracket]i, 
                                7\[RightDoubleBracket], 
                              RC\[RightDoubleBracket]*
                            Min[1, 
                                TotNoDays\[LeftDoubleBracket]
                                    i\[RightDoubleBracket]/365]/100] - 
                        Firm\[LeftDoubleBracket]i, 10\[RightDoubleBracket]*
                          TransMat\[LeftDoubleBracket]
                              Firm\[LeftDoubleBracket]i, 
                                7\[RightDoubleBracket], 
                              RC\[RightDoubleBracket]/100*
                          Min[1, 
                            TotNoDays\[LeftDoubleBracket]i\
\[RightDoubleBracket]/365])\)/
                    Sqrt[1 - 
                        VR\[LeftDoubleBracket]i\[RightDoubleBracket]]])\)*
            VEAD\[LeftDoubleBracket]i\[RightDoubleBracket], {i, 1, 
            n}];\)\), "\[IndentingNewLine]", 
    \(Sum[
      PoJednom995\[LeftDoubleBracket]i\[RightDoubleBracket], {i, 1, 
        n}]\), "\[IndentingNewLine]", 
    \(\(PoJednom998 = 
        Table[\((Firm\[LeftDoubleBracket]i, 10\[RightDoubleBracket]*
                CDF[ND, \((Quantile[ND, 0.998]*
                          Sqrt[VR\[LeftDoubleBracket]i\[RightDoubleBracket]] \
+ Quantile[ND, TransMat\[LeftDoubleBracket]Firm\[LeftDoubleBracket]i, 
                                7\[RightDoubleBracket], 
                              RC\[RightDoubleBracket]*
                            Min[1, 
                                TotNoDays\[LeftDoubleBracket]i\
\[RightDoubleBracket]/365]/100] - 
                        Firm\[LeftDoubleBracket]i, 10\[RightDoubleBracket]*
                          TransMat\[LeftDoubleBracket]Firm\[LeftDoubleBracket]\
i, 7\[RightDoubleBracket], RC\[RightDoubleBracket]/100*
                          Min[1, 
                            TotNoDays\[LeftDoubleBracket]i\
\[RightDoubleBracket]/365])\)/
                    Sqrt[1 - 
                        VR\[LeftDoubleBracket]i\[RightDoubleBracket]]])\)*
            VEAD\[LeftDoubleBracket]i\[RightDoubleBracket], {i, 1, 
            n}];\)\), "\[IndentingNewLine]", 
    \(Sum[
      PoJednom998\[LeftDoubleBracket]i\[RightDoubleBracket], {i, 1, 
        n}]\), "\[IndentingNewLine]", 
    \(\(PoJednom999 = 
        Table[\((Firm\[LeftDoubleBracket]i, 10\[RightDoubleBracket]*
                CDF[ND, \((Quantile[ND, 0.999]*
                          Sqrt[VR\[LeftDoubleBracket]i\[RightDoubleBracket]] \
+ Quantile[ND, TransMat\[LeftDoubleBracket]Firm\[LeftDoubleBracket]i, 
                                7\[RightDoubleBracket], 
                              RC\[RightDoubleBracket]*
                            Min[1, 
                                TotNoDays\[LeftDoubleBracket]i\
\[RightDoubleBracket]/365]/100] - 
                        Firm\[LeftDoubleBracket]i, 10\[RightDoubleBracket]*
                          TransMat\[LeftDoubleBracket]
                              Firm\[LeftDoubleBracket]i, 
                                7\[RightDoubleBracket], 
                              RC\[RightDoubleBracket]/100*
                          Min[1, 
                            TotNoDays\[LeftDoubleBracket]
                                i\[RightDoubleBracket]/365])\)/
                    Sqrt[1 - 
                        VR\[LeftDoubleBracket]i\[RightDoubleBracket]]])\)*
            VEAD\[LeftDoubleBracket]i\[RightDoubleBracket], {i, 1, 
            n}];\)\), "\[IndentingNewLine]", 
    \(Sum[
      PoJednom999\[LeftDoubleBracket]i\[RightDoubleBracket], {i, 1, 
        n}]\)}], "Input"],

Cell[BoxData[
    \(OcekZtrata = 
      Sum[VEAD\[LeftDoubleBracket]i\[RightDoubleBracket]*
          Firm\[LeftDoubleBracket]i, 10\[RightDoubleBracket]*
          TransMat\[LeftDoubleBracket]
            Firm\[LeftDoubleBracket]i, 7\[RightDoubleBracket], 
            RC\[RightDoubleBracket]*
          Min[1, TotNoDays\[LeftDoubleBracket]i\[RightDoubleBracket]/365]/
            100, {i, 1, n}]\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Z\[AAcute]v\:011br - srovn\[AAcute]n\[IAcute] metod",
  FontColor->RGBColor[1, 0, 0]]], "Subtitle"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["O\[CHacek]ek\[AAcute]van\[AAcute] ztr\[AAcute]ta",
  FontColor->RGBColor[1, 0, 0]]], "Subsection"],

Cell[BoxData[
    \(\(\( (*\ Ocekavana\ ztrata\ ZAPORNA\  = \ zisk, \ 
      kdyz\ pocitam\ s\ uroky\ *) \)\(\[IndentingNewLine]\)\(\[Mu] = 
      PV - EX\[IndentingNewLine] (*\ 
      Tohle\ je\ ztrata\ KLADNA\ od\ Vasicka, \ 
      kdyz\ bych\ neuvazoval\ uroky\ *) \[IndentingNewLine]
    OcekZtrata\)\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Neo\[CHacek]ek\[AAcute]van\[AAcute] ztr\[AAcute]ta",
    FontColor->RGBColor[1, 0, 0]],
  "\t"
}], "Subsection"],

Cell[BoxData[{
    \(CMNeocek = {KPCredit1\[LeftDoubleBracket]3\[RightDoubleBracket], 
        KPCredit2\[LeftDoubleBracket]3\[RightDoubleBracket], 
        KPCredit3\[LeftDoubleBracket]3\[RightDoubleBracket], 
        KPCredit4\[LeftDoubleBracket]3\[RightDoubleBracket]}\), "\
\[IndentingNewLine]", 
    \(\(VacicekNeocek = {Sum[
            PoJednom990\[LeftDoubleBracket]i\[RightDoubleBracket], {i, 1, 
              n}], Sum[
            PoJednom995\[LeftDoubleBracket]i\[RightDoubleBracket], {i, 1, 
              n}], Sum[
            PoJednom998\[LeftDoubleBracket]i\[RightDoubleBracket], {i, 1, 
              n}], Sum[
            PoJednom999\[LeftDoubleBracket]i\[RightDoubleBracket], {i, 1, 
              n}]};\)\)}], "Input"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 911}},
WindowSize->{1262, 877},
WindowMargins->{{0, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 84, 1, 64, "Subtitle"],

Cell[CellGroupData[{
Cell[1885, 58, 82, 1, 47, "Subsection"],
Cell[1970, 61, 880, 16, 223, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[2887, 82, 93, 1, 31, "Subsection"],
Cell[2983, 85, 527, 16, 90, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[3547, 106, 90, 1, 31, "Subsection"],
Cell[3640, 109, 396, 10, 90, "Text"],
Cell[4039, 121, 573, 10, 210, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[4649, 136, 92, 1, 31, "Subsection"],
Cell[4744, 139, 502, 11, 110, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[5283, 155, 89, 1, 31, "Subsection"],

Cell[CellGroupData[{
Cell[5397, 160, 117, 4, 43, "Subsubsection"],
Cell[5517, 166, 224, 5, 70, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5778, 176, 122, 4, 43, "Subsubsection"],
Cell[5903, 182, 1194, 26, 90, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7134, 213, 132, 4, 43, "Subsubsection"],
Cell[7269, 219, 407, 9, 90, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7713, 233, 130, 4, 43, "Subsubsection"],
Cell[7846, 239, 527, 11, 90, "Input"],
Cell[8376, 252, 1217, 24, 110, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9630, 281, 115, 4, 43, "Subsubsection"],
Cell[9748, 287, 1299, 23, 130, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11084, 315, 126, 4, 43, "Subsubsection"],
Cell[11213, 321, 654, 14, 110, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11904, 340, 109, 4, 43, "Subsubsection"],
Cell[12016, 346, 1149, 19, 110, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[13214, 371, 98, 1, 31, "Subsection"],

Cell[CellGroupData[{
Cell[13337, 376, 120, 4, 43, "Subsubsection"],
Cell[13460, 382, 4386, 75, 350, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[17895, 463, 92, 1, 31, "Subsection"],

Cell[CellGroupData[{
Cell[18012, 468, 117, 4, 43, "Subsubsection"],
Cell[18132, 474, 717, 14, 50, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18886, 493, 105, 4, 43, "Subsubsection"],
Cell[18994, 499, 345, 8, 70, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19376, 512, 117, 4, 43, "Subsubsection"],
Cell[19496, 518, 909, 18, 90, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[20454, 542, 89, 1, 31, "Subsection"],

Cell[CellGroupData[{
Cell[20568, 547, 228, 5, 43, "Subsubsection"],
Cell[20799, 554, 1518, 31, 90, "Input"],
Cell[22320, 587, 3168, 62, 290, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[25525, 654, 183, 5, 43, "Subsubsection"],
Cell[25711, 661, 443, 8, 30, "Input"],
Cell[26157, 671, 2667, 47, 150, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28861, 723, 137, 4, 43, "Subsubsection"],
Cell[29001, 729, 333, 5, 30, "Input"],
Cell[29337, 736, 221, 3, 30, "Input"],
Cell[29561, 741, 2696, 63, 350, "Input"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[32318, 811, 79, 1, 64, "Subtitle"],
Cell[32400, 814, 67, 1, 30, "Input"],
Cell[32470, 817, 9117, 165, 790, "Input"],
Cell[41590, 984, 409, 8, 30, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[42036, 997, 123, 1, 53, "Subtitle"],

Cell[CellGroupData[{
Cell[42184, 1002, 122, 1, 47, "Subsection"],
Cell[42309, 1005, 319, 6, 90, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[42665, 1016, 140, 4, 31, "Subsection"],
Cell[42808, 1022, 738, 14, 50, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

